@@ -3,7 +3,7 @@
 ###use Data::Dumper ; print Dumper( $world ) ;
 
 use Test;
-BEGIN { plan tests => 28 } ;
+BEGIN { plan tests => 29 } ;
 
 use Safe::World ;
 
@@ -26,19 +26,19 @@ use warnings ;
   ) ;
   
   $world->eval(q`
-    my $time = time  ;
     print "Test1 "  ;
+    print STDERR "ERROR!\n" ;
     warn("Alert!!!") ;
     foreach my $Key (sort keys %ENV ) {
       print "<$Key = $ENV{$Key}>" ;
     }
   `);
-  
+
   $stderr =~ s/eval \d+/eval x/gi ;
   
   ok($stdout , "Test1 <BAZ = BRAS><FOO = bar>") ;
-  ok($stderr , "Alert!!! at (eval x) line 4.\n") ;
-
+  ok($stderr , "ERROR!\nAlert!!! at (eval x) line 4.\n") ;
+  
 }
 #########################
 {
@@ -53,7 +53,7 @@ use warnings ;
   
   $world->eval(q`
     use strict ;
-    my @inc = keys %INC ;
+    my @inc = sort keys %INC ;
     print "\@INC: $#INC\n" if @INC ;
     print "%INC: @inc\n" ;
   `);
@@ -90,6 +90,28 @@ use warnings ;
   ok($stdout , "SUBTEST <> SUBTEST <123 456> SUBTEST <> SUBTEST <outside> ");
   ok($stderr , '') ;
 
+}
+#########################
+{
+
+  my ( $stdout , $stderr ) ;
+
+  my $world = Safe::World->new(
+  stdout => \$stdout ,
+  stderr => \$stderr ,
+  flush  => 1 ,
+  ) ;
+  
+  $world->eval(q`
+    use test::shared ;
+    my @incs = sort keys %INC ;
+    print "incs> @incs\n" ;
+  `);
+
+  $world = undef ;
+  
+  ok($stdout , "incs> strict.pm test/shared.pm\n");
+
 }
 #########################
 {
@@ -105,7 +127,7 @@ use warnings ;
   $world0->eval(q`
     use test::shared ;
     
-    my @incs = keys %INC ;
+    my @incs = sort keys %INC ;
     print "incs> @incs\n" ;
     
     $TEST = 'w0' ;
@@ -124,7 +146,7 @@ use warnings ;
   $world1->link_pack("$world0->{ROOT}::test::shared") ;
   
   $world1->eval(q`
-    my @incs = keys %INC ;
+    my @incs = sort keys %INC ;
     print "incs> @incs\n" ;
     
     $TEST = 'w1' ;
@@ -143,7 +165,7 @@ use warnings ;
   $world2->link_pack("$world0->{ROOT}::test::shared") ;
   
   $world2->eval(q`
-    my @incs = keys %INC ;
+    my @incs = sort keys %INC ;
     print "incs> @incs\n" ;
     
     $TEST = 'w2' ;
@@ -151,17 +173,17 @@ use warnings ;
     test::shared::method(2) ;
   `);
   
-  ok($stdout0 , "incs> test/shared.pm\n>> foovar\nSHARED[1]! [w0][w0] <<0>>\n");
+  ok($stdout0 , "incs> strict.pm test/shared.pm\n>> foovar\nSHARED[1]! [w0][w0] <<0>>\n");
   ok($stderr0 , '') ;
 
-  ok($stdout1 , "incs> \n>> foovar\nSHARED[2]! [w0][w1] <<1>>\n");
+  ok($stdout1 , "incs> strict.pm\n>> foovar\nSHARED[2]! [w0][w1] <<1>>\n");
   ok($stderr1 , '') ;
 
-  ok($stdout2 , "incs> \n>> foovar\nSHARED[3]! [w0][w2] <<2>>\n");
+  ok($stdout2 , "incs> strict.pm\n>> foovar\nSHARED[3]! [w0][w2] <<2>>\n");
   ok($stderr2 , '') ;
   
   ok($INC{'test/shared.pm'} , undef) ;
-  
+
 }
 #########################
 {
@@ -176,7 +198,7 @@ use warnings ;
   
   $world0->eval(q`
     use test::shared ;
-    my @incs = keys %INC ;
+    my @incs = sort keys %INC ;
     print "incs> @incs\n" ;
     
     $TEST = 'w0' ;
@@ -199,7 +221,7 @@ use warnings ;
   ok($world0->{WORLD_SHARED}, $world1->{ROOT}) ;
   
   $world1->eval(q`
-    my @incs = keys %INC ;
+    my @incs = sort keys %INC ;
     print "incs> @incs\n" ;
     
     $TEST = 'w1' ;
@@ -222,7 +244,7 @@ use warnings ;
   ok($world0->{WORLD_SHARED}, $world2->{ROOT}) ;
   
   $world2->eval(q`
-    my @incs = keys %INC ;
+    my @incs = sort keys %INC ;
     print "incs> @incs\n" ;
     
     $TEST = 'w2' ;
@@ -230,15 +252,22 @@ use warnings ;
     test::shared::method(2) ;
   `);
   
-  $world1->unlink_world($world0) ;  
+  $world2->unlink_world($world0) ;  
   
-  ok($stdout0 , "incs> test/shared.pm\n>> foovar\nSHARED[1]! [w0][w0] <<0>>\n");
+  $world0->eval(q`
+    my @incs = sort keys %INC ;
+    print "incs> @incs\n" ;
+    print ">> $test::shared::VAR\n" ;
+    test::shared::method('0.1') ;
+  `);
+  
+  ok($stdout0 , "incs> strict.pm test/shared.pm\n>> foovar\nSHARED[1]! [w0][w0] <<0>>\nincs> strict.pm test/shared.pm\n>> foovar\nSHARED[4]! [w0][w0] <<0.1>>\n");
   ok($stderr0 , '') ;
 
-  ok($stdout1 , "incs> \n>> foovar\nSHARED[2]! [w1][w1] <<1>>\n");
+  ok($stdout1 , "incs> strict.pm\n>> foovar\nSHARED[2]! [w1][w1] <<1>>\n");
   ok($stderr1 , '') ;
 
-  ok($stdout2 , "incs> \n>> foovar\nSHARED[3]! [w2][w2] <<2>>\n");
+  ok($stdout2 , "incs> strict.pm\n>> foovar\nSHARED[3]! [w2][w2] <<2>>\n");
   ok($stderr2 , '') ;
 
 }
@@ -256,11 +285,10 @@ use warnings ;
   ) ;
   
   $world->eval(q`
-    my $time = time ;
     print "Test1 " ;
   `);
   
-  ok($stdout , "SELECT UNSELECT SELECT UNSELECT SELECT Test1 UNSELECT ") ;
+  ok($stdout , "SELECT UNSELECT SELECT UNSELECT SELECT UNSELECT SELECT Test1 UNSELECT ") ;
   ok($stderr , '') ;
 
 }
